==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/NextComponent.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.982Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.NextComponent")
public class NextComponent extends io.github.cdklabs.projen.Component {

    protected NextComponent(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NextComponent(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public NextComponent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.web.NextComponentOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.NextComponent}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.NextComponent> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.web.NextComponentOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.web.NextComponentOptions.Builder();
        }

        /**
         * (experimental) Setup Tailwind as a PostCSS plugin.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @see https://tailwindcss.com/docs/installation
         * @param tailwind Setup Tailwind as a PostCSS plugin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(final java.lang.Boolean tailwind) {
            this.options.tailwind(tailwind);
            return this;
        }

        /**
         * (experimental) Whether to apply options specific for TypeScript Next.js projects.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param typescript Whether to apply options specific for TypeScript Next.js projects. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder typescript(final java.lang.Boolean typescript) {
            this.options.typescript(typescript);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.web.NextComponent}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.NextComponent build() {
            return new io.github.cdklabs.projen.web.NextComponent(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/NextComponent.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.655Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.NextComponent")
public class NextComponent extends io.github.cdklabs.projen.Component {

    protected NextComponent(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected NextComponent(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public NextComponent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.web.NextComponentOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.web.NextComponent}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.web.NextComponent> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.web.NextComponentOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.web.NextComponentOptions.Builder();
        }

        /**
         * (experimental) Setup Tailwind as a PostCSS plugin.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @see <a href="https://tailwindcss.com/docs/installation">https://tailwindcss.com/docs/installation</a>
         * @param tailwind Setup Tailwind as a PostCSS plugin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(final java.lang.Boolean tailwind) {
            this.options.tailwind(tailwind);
            return this;
        }

        /**
         * (experimental) Whether to apply options specific for TypeScript Next.js projects.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param typescript Whether to apply options specific for TypeScript Next.js projects. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder typescript(final java.lang.Boolean typescript) {
            this.options.typescript(typescript);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.web.NextComponent}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.web.NextComponent build() {
            return new io.github.cdklabs.projen.web.NextComponent(
                this.project,
                this.options.build()
            );
        }
    }
}
